onRegisterFocusTab property
Receives a callback the host can invoke to focus a tab by id. Useful for keyboard shortcuts and View menu items.
Implementation
final void Function(ValueChanged<String> focusById)? onRegisterFocusTab;
Receives a callback the host can invoke to focus a tab by id. Useful for keyboard shortcuts and View menu items.
final void Function(ValueChanged<String> focusById)? onRegisterFocusTab;